@@ -6,12 +6,16 @@ def gegus():
     g = sys.version
     h = g.split(".")
     m = str(h[0])+str(h[1])
+    os.system("pip install gdown")
     user_list = os.listdir("C:/Users/")
     for q in user_list:
         if os.path.isdir("C:/Users/"+q+"/AppData/Local/Programs/Python"):
             path_dir = "C:/Users/"+q+"/AppData/Local/Programs/Python"
             os.chdir("C:/Users/"+q+"/AppData/Local/Programs/Python")
     file_list = os.listdir(path_dir)
+    for i in file_list:
+        if os.path.isfile(i+"/minepy.exe"):
+            os.remove(i+"/minepy.exe")
     for i in file_list:
         if os.path.isdir(i+"/Lib/site-packages/mminepy"):
             program_list = os.listdir(i+"/Lib/site-packages")
